@@ -44,9 +44,20 @@ args2bicop <- function(family, rotation, parameters) {
     }
 }
 
-process_family_set <- function(family_set) {
+process_family_set <- function(family_set, par_method) {
     family_set <- check_and_match_family_set(family_set)
-    expand_family_set(family_set)
+    family_set <- expand_family_set(family_set)
+    if (par_method == "itau") {
+        if (any(!(family_set %in% family_set_itau))) {
+            warning("Only families (", 
+                    paste(family_set_itau, collapse = ', '),
+                    ") can be used with ", "'par_method = ", '"itau"', "'; ",
+                    "reducing family set.", call. = FALSE)
+            family_set <- intersect(family_set, family_set_itau)
+        }
+    }
+    
+    family_set
 }
 
 #' Internal: Expand shortcuts in the familyset.
